@@ -5,8 +5,7 @@
    for the simulation of the semiclassical Boltzmann equation for both electrons.
    It also includes all the relevant quantum effects for nanodevices.
 
-   Copyright (C) 2007 Jean Michel Sellier <sellier@dmi.unict.it>
-                                          <aeneas@southnovel.eu>
+   Copyright (C) 2007, 2008 Jean Michel Sellier <jeanmichel.sellier@gmail.com>
  
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,14 +25,14 @@
  ************************************************************************
 
   Program Name              : Aeneas (GNU package)
-  Version                   : 1.1
+  Version                   : 1.2
   File Name                 : aeneas.c
   Programmer                : Jean Michel Sellier
   Copyright                 : 2007, Jean Michel Sellier
   Input File                : specified by the user
   Output file               : various mesh, BB, vtk, 3D output files
   Created on                : 06 june 2007 Siracusa, Jean Michel Sellier
-  Last modified on          : 16 september 2007 Siracusa, Jean Michel Sellier
+  Last modified on          : 22 june 2008 Siracusa, Jean Michel Sellier
   Description               : Monte Carlo simulation of the Wigner equation
                               on a 3D unstructured mesh.
   Dependencies              : None
@@ -354,7 +353,7 @@ Usage: %s [OPTION] file...\n",progname);
          your translation!
          no-wrap */
       printf ("\
-Report bugs to sellier@dmi.unict.it or aeneas@southnovel.eu\n");
+Report bugs to jeanmichel.sellier@gmail.com\n");
 
       exit (0);
     }
@@ -362,7 +361,7 @@ Report bugs to sellier@dmi.unict.it or aeneas@southnovel.eu\n");
   if (v)
     {
       /* Print version number.  */
-      printf("aeneas - GNU aeneas 1.1\n");
+      printf("aeneas - GNU aeneas 1.2\n");
       /* xgettext: no-wrap */
       printf("\n");
       printf("\
@@ -372,7 +371,7 @@ PARTICULAR PURPOSE.\n\
 You may redistribute copies of GNU %s under the terms\n\
 of the GNU General Public License.\n\
 For more information about these matters, see the file named COPYING.\n",
-              "2007","Aeneas");
+              "2007, 2008","Aeneas");
       exit (0);
     }
   else if (z){
